# mypy-boto3-chime

[![PyPI - mypy-boto3-chime](https://img.shields.io/pypi/v/mypy-boto3-chime.svg?color=blue)](https://pypi.org/project/mypy-boto3-chime)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-chime.svg?color=blue)](https://pypi.org/project/mypy-boto3-chime)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-chime?color=blue)](https://pypistats.org/packages/mypy-boto3-chime)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Chime 1.17.61](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/chime.html#Chime) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.7.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-chime](#mypy-boto3-chime)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)

## How to install

Install `boto3-stubs` for `Chime` service.

```bash
python -m pip install boto3-stubs[chime]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[chime]` in your environment: `python -m pip install 'boto3-stubs[chime]'`

Both type checking and auto-complete should work for `Chime` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[chime]` in your environment: `python -m pip install 'boto3-stubs[chime]'`

Both type checking and auto-complete should work for `Chime` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[chime]` in your environment: `python -m pip install 'boto3-stubs[chime]'`
- Run `mypy` as usual

Type checking should work for `Chime` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[chime]` in your environment: `python -m pip install 'boto3-stubs[chime]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Chime` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`ChimeClient` provides annotations for `boto3.client("chime")`.

```python
import boto3

from mypy_boto3_chime import ChimeClient

client: ChimeClient = boto3.client("chime")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ChimeClient = session.client("chime")
```

### Paginators annotations

`mypy_boto3_chime.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_chime import ChimeClient
from mypy_boto3_chime.paginator import (
    ListAccountsPaginator,
    ListUsersPaginator,
)

client: ChimeClient = boto3.client("chime")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_accounts_paginator: ListAccountsPaginator = client.get_paginator("list_accounts")
list_users_paginator: ListUsersPaginator = client.get_paginator("list_users")
```







### Literals

`mypy_boto3_chime.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_chime.literals import (
    AccountType,
    AppInstanceDataType,
    BotType,
    CallingNameStatus,
    Capability,
    ChannelMembershipType,
    ChannelMessagePersistenceType,
    ChannelMessageType,
    ChannelMode,
    ChannelPrivacy,
    EmailStatus,
    ErrorCode,
    GeoMatchLevel,
    InviteStatus,
    License,
    ListAccountsPaginatorName,
    ListUsersPaginatorName,
    MemberType,
    NotificationTarget,
    NumberSelectionBehavior,
    OrderedPhoneNumberStatus,
    OriginationRouteProtocol,
    PhoneNumberAssociationName,
    PhoneNumberOrderStatus,
    PhoneNumberProductType,
    PhoneNumberStatus,
    PhoneNumberType,
    ProxySessionStatus,
    RegistrationStatus,
    RoomMembershipRole,
    SipRuleTriggerType,
    SortOrder,
    UserType,
    VoiceConnectorAwsRegion,
)

def check_value(value: AccountType) -> bool:
    ...
```



### Typed dictionaries

`mypy_boto3_chime.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_chime.type_defs import (
    AccountSettingsTypeDef,
    AccountTypeDef,
    AlexaForBusinessMetadataTypeDef,
    AppInstanceAdminSummaryTypeDef,
    AppInstanceAdminTypeDef,
    AppInstanceRetentionSettingsTypeDef,
    AppInstanceStreamingConfigurationTypeDef,
    AppInstanceSummaryTypeDef,
    AppInstanceTypeDef,
    AppInstanceUserMembershipSummaryTypeDef,
    AppInstanceUserSummaryTypeDef,
    AppInstanceUserTypeDef,
    AttendeeTypeDef,
    BotTypeDef,
    BusinessCallingSettingsTypeDef,
    ChannelBanSummaryTypeDef,
    ChannelBanTypeDef,
    ChannelMembershipForAppInstanceUserSummaryTypeDef,
    ChannelMembershipSummaryTypeDef,
    ChannelMembershipTypeDef,
    ChannelMessageSummaryTypeDef,
    ChannelMessageTypeDef,
    ChannelModeratedByAppInstanceUserSummaryTypeDef,
    ChannelModeratorSummaryTypeDef,
    ChannelModeratorTypeDef,
    ChannelRetentionSettingsTypeDef,
    ChannelSummaryTypeDef,
    ChannelTypeDef,
    ConversationRetentionSettingsTypeDef,
    CreateAttendeeErrorTypeDef,
    DNISEmergencyCallingConfigurationTypeDef,
    EmergencyCallingConfigurationTypeDef,
    EventsConfigurationTypeDef,
    GeoMatchParamsTypeDef,
    IdentityTypeDef,
    InviteTypeDef,
    LoggingConfigurationTypeDef,
    MediaPlacementTypeDef,
    MeetingTypeDef,
    MemberErrorTypeDef,
    MemberTypeDef,
    MessagingSessionEndpointTypeDef,
    OrderedPhoneNumberTypeDef,
    OriginationRouteTypeDef,
    OriginationTypeDef,
    ParticipantTypeDef,
    PhoneNumberAssociationTypeDef,
    PhoneNumberCapabilitiesTypeDef,
    PhoneNumberErrorTypeDef,
    PhoneNumberOrderTypeDef,
    PhoneNumberTypeDef,
    ProxySessionTypeDef,
    ProxyTypeDef,
    RetentionSettingsTypeDef,
    RoomMembershipTypeDef,
    RoomRetentionSettingsTypeDef,
    RoomTypeDef,
    SigninDelegateGroupTypeDef,
    SipMediaApplicationCallTypeDef,
    SipMediaApplicationEndpointTypeDef,
    SipMediaApplicationLoggingConfigurationTypeDef,
    SipMediaApplicationTypeDef,
    SipRuleTargetApplicationTypeDef,
    SipRuleTypeDef,
    StreamingConfigurationTypeDef,
    StreamingNotificationTargetTypeDef,
    TagTypeDef,
    TelephonySettingsTypeDef,
    TerminationHealthTypeDef,
    TerminationTypeDef,
    UserErrorTypeDef,
    UserSettingsTypeDef,
    UserTypeDef,
    VoiceConnectorGroupTypeDef,
    VoiceConnectorItemTypeDef,
    VoiceConnectorSettingsTypeDef,
    VoiceConnectorTypeDef,
    AssociatePhoneNumbersWithVoiceConnectorGroupResponseTypeDef,
    AssociatePhoneNumbersWithVoiceConnectorResponseTypeDef,
    BatchCreateAttendeeResponseTypeDef,
    BatchCreateRoomMembershipResponseTypeDef,
    BatchDeletePhoneNumberResponseTypeDef,
    BatchSuspendUserResponseTypeDef,
    BatchUnsuspendUserResponseTypeDef,
    BatchUpdatePhoneNumberResponseTypeDef,
    BatchUpdateUserResponseTypeDef,
    CreateAccountResponseTypeDef,
    CreateAppInstanceAdminResponseTypeDef,
    CreateAppInstanceResponseTypeDef,
    CreateAppInstanceUserResponseTypeDef,
    CreateAttendeeRequestItemTypeDef,
    CreateAttendeeResponseTypeDef,
    CreateBotResponseTypeDef,
    CreateChannelBanResponseTypeDef,
    CreateChannelMembershipResponseTypeDef,
    CreateChannelModeratorResponseTypeDef,
    CreateChannelResponseTypeDef,
    CreateMeetingDialOutResponseTypeDef,
    CreateMeetingResponseTypeDef,
    CreateMeetingWithAttendeesResponseTypeDef,
    CreatePhoneNumberOrderResponseTypeDef,
    CreateProxySessionResponseTypeDef,
    CreateRoomMembershipResponseTypeDef,
    CreateRoomResponseTypeDef,
    CreateSipMediaApplicationCallResponseTypeDef,
    CreateSipMediaApplicationResponseTypeDef,
    CreateSipRuleResponseTypeDef,
    CreateUserResponseTypeDef,
    CreateVoiceConnectorGroupResponseTypeDef,
    CreateVoiceConnectorResponseTypeDef,
    CredentialTypeDef,
    DescribeAppInstanceAdminResponseTypeDef,
    DescribeAppInstanceResponseTypeDef,
    DescribeAppInstanceUserResponseTypeDef,
    DescribeChannelBanResponseTypeDef,
    DescribeChannelMembershipForAppInstanceUserResponseTypeDef,
    DescribeChannelMembershipResponseTypeDef,
    DescribeChannelModeratedByAppInstanceUserResponseTypeDef,
    DescribeChannelModeratorResponseTypeDef,
    DescribeChannelResponseTypeDef,
    DisassociatePhoneNumbersFromVoiceConnectorGroupResponseTypeDef,
    DisassociatePhoneNumbersFromVoiceConnectorResponseTypeDef,
    GetAccountResponseTypeDef,
    GetAccountSettingsResponseTypeDef,
    GetAppInstanceRetentionSettingsResponseTypeDef,
    GetAppInstanceStreamingConfigurationsResponseTypeDef,
    GetAttendeeResponseTypeDef,
    GetBotResponseTypeDef,
    GetChannelMessageResponseTypeDef,
    GetEventsConfigurationResponseTypeDef,
    GetGlobalSettingsResponseTypeDef,
    GetMeetingResponseTypeDef,
    GetMessagingSessionEndpointResponseTypeDef,
    GetPhoneNumberOrderResponseTypeDef,
    GetPhoneNumberResponseTypeDef,
    GetPhoneNumberSettingsResponseTypeDef,
    GetProxySessionResponseTypeDef,
    GetRetentionSettingsResponseTypeDef,
    GetRoomResponseTypeDef,
    GetSipMediaApplicationLoggingConfigurationResponseTypeDef,
    GetSipMediaApplicationResponseTypeDef,
    GetSipRuleResponseTypeDef,
    GetUserResponseTypeDef,
    GetUserSettingsResponseTypeDef,
    GetVoiceConnectorEmergencyCallingConfigurationResponseTypeDef,
    GetVoiceConnectorGroupResponseTypeDef,
    GetVoiceConnectorLoggingConfigurationResponseTypeDef,
    GetVoiceConnectorOriginationResponseTypeDef,
    GetVoiceConnectorProxyResponseTypeDef,
    GetVoiceConnectorResponseTypeDef,
    GetVoiceConnectorStreamingConfigurationResponseTypeDef,
    GetVoiceConnectorTerminationHealthResponseTypeDef,
    GetVoiceConnectorTerminationResponseTypeDef,
    InviteUsersResponseTypeDef,
    ListAccountsResponseTypeDef,
    ListAppInstanceAdminsResponseTypeDef,
    ListAppInstanceUsersResponseTypeDef,
    ListAppInstancesResponseTypeDef,
    ListAttendeeTagsResponseTypeDef,
    ListAttendeesResponseTypeDef,
    ListBotsResponseTypeDef,
    ListChannelBansResponseTypeDef,
    ListChannelMembershipsForAppInstanceUserResponseTypeDef,
    ListChannelMembershipsResponseTypeDef,
    ListChannelMessagesResponseTypeDef,
    ListChannelModeratorsResponseTypeDef,
    ListChannelsModeratedByAppInstanceUserResponseTypeDef,
    ListChannelsResponseTypeDef,
    ListMeetingTagsResponseTypeDef,
    ListMeetingsResponseTypeDef,
    ListPhoneNumberOrdersResponseTypeDef,
    ListPhoneNumbersResponseTypeDef,
    ListProxySessionsResponseTypeDef,
    ListRoomMembershipsResponseTypeDef,
    ListRoomsResponseTypeDef,
    ListSipMediaApplicationsResponseTypeDef,
    ListSipRulesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListUsersResponseTypeDef,
    ListVoiceConnectorGroupsResponseTypeDef,
    ListVoiceConnectorTerminationCredentialsResponseTypeDef,
    ListVoiceConnectorsResponseTypeDef,
    MeetingNotificationConfigurationTypeDef,
    MembershipItemTypeDef,
    PaginatorConfigTypeDef,
    PutAppInstanceRetentionSettingsResponseTypeDef,
    PutAppInstanceStreamingConfigurationsResponseTypeDef,
    PutEventsConfigurationResponseTypeDef,
    PutRetentionSettingsResponseTypeDef,
    PutSipMediaApplicationLoggingConfigurationResponseTypeDef,
    PutVoiceConnectorEmergencyCallingConfigurationResponseTypeDef,
    PutVoiceConnectorLoggingConfigurationResponseTypeDef,
    PutVoiceConnectorOriginationResponseTypeDef,
    PutVoiceConnectorProxyResponseTypeDef,
    PutVoiceConnectorStreamingConfigurationResponseTypeDef,
    PutVoiceConnectorTerminationResponseTypeDef,
    RedactChannelMessageResponseTypeDef,
    RegenerateSecurityTokenResponseTypeDef,
    ResetPersonalPINResponseTypeDef,
    RestorePhoneNumberResponseTypeDef,
    SearchAvailablePhoneNumbersResponseTypeDef,
    SendChannelMessageResponseTypeDef,
    UpdateAccountResponseTypeDef,
    UpdateAppInstanceResponseTypeDef,
    UpdateAppInstanceUserResponseTypeDef,
    UpdateBotResponseTypeDef,
    UpdateChannelMessageResponseTypeDef,
    UpdateChannelReadMarkerResponseTypeDef,
    UpdateChannelResponseTypeDef,
    UpdatePhoneNumberRequestItemTypeDef,
    UpdatePhoneNumberResponseTypeDef,
    UpdateProxySessionResponseTypeDef,
    UpdateRoomMembershipResponseTypeDef,
    UpdateRoomResponseTypeDef,
    UpdateSipMediaApplicationResponseTypeDef,
    UpdateSipRuleResponseTypeDef,
    UpdateUserRequestItemTypeDef,
    UpdateUserResponseTypeDef,
    UpdateVoiceConnectorGroupResponseTypeDef,
    UpdateVoiceConnectorResponseTypeDef,
)

def get_structure() -> AccountSettingsTypeDef:
    return {
      ...
    }
```
